# Change Log

All notable changes to this project will be documented in this file.

## [v0.0.3] - 20231129

Updated docstrings and published [docs](https://rhettbull.github.io/clirunner/)

## [v0.0.2] - 20231128

Updated docs to include more examples of how to use CliRunner()

## [v0.0.1] - 20231128

Initial release
